@@ -1,8 +1,9 @@
 package Moose::Autobox::Array;
 use Moose::Role 'with';
+use Perl6::Junction;
 use autobox;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 with 'Moose::Autobox::Ref',
      'Moose::Autobox::List',
@@ -35,7 +36,12 @@ sub delete {
 sub shift { 
     my ($array) = @_;    
     CORE::shift @$array; 
-}     
+}    
+
+sub slice {
+    my ($array, $indicies) = @_;
+    [ @{$array}[ @{$indicies} ] ];
+} 
 
 # NOTE: 
 # sprintf args need to be reversed, 
@@ -111,6 +117,28 @@ sub kv {
     $array->keys->map(sub { [ $_, $array->[$_] ] });
 }
 
+## Junctions
+
+sub all {
+    my ($array) = @_;     
+    return Perl6::Junction::All->all(@$array);
+}
+
+sub any {
+    my ($array) = @_;     
+    return Perl6::Junction::Any->any(@$array);
+}
+
+sub none {
+    my ($array) = @_;     
+    return Perl6::Junction::None->none(@$array);
+}
+
+sub one {
+    my ($array) = @_; 
+    return Perl6::Junction::One->one(@$array);
+}
+
 1;
 
 __END__
@@ -133,6 +161,8 @@ Moose::Autobox::Array - the Array role
   print "Squares: " . [ 1 .. 10 ]->map(sub { $_ * $_ })->join(', ');
   
   print [ 1, 'number' ]->sprintf('%d is the loneliest %s');
+  
+  print ([ 1 .. 5 ]->any == 3) ? 'true' : 'false'; # prints 'true'
 
 =head1 DESCRIPTION
 
@@ -154,6 +184,8 @@ This is a role to describe operations on the Array type.
 
 =item B<sprintf ($format_string)>
 
+=item B<slice (@indices)>
+
 =back
 
 =head2 Indexed implementation
@@ -196,6 +228,20 @@ This is a role to describe operations on the Array type.
 
 =back
 
+=head2 Junctions
+
+=over 4
+
+=item B<all>
+
+=item B<any>
+
+=item B<none>
+
+=item B<one>
+
+=back
+
 =over 4
 
 =item B<meta>
@@ -221,4 +267,4 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
